@@ -10,8 +10,9 @@ from util_hj3415 import noti, utils
 from eval_hj3415 import report, score
 from krx_hj3415 import krx
 from db_hj3415 import mongo2, dbpath
-from . import subjects, data
-from .opendart import Dart, DartInfo
+from dart_hj3415 import subjects
+from dart_hj3415 import data
+from dart_hj3415.opendart import Dart, DartInfo
 
 import logging
 logger = logging.getLogger(__name__)
@@ -284,8 +285,11 @@ def run_all_subjects(edate: str) -> int:
         try:
             for subject in enabled_subject:
                 AnalyseOneSubject(client, driver, edate=edate, subject=subject, pkl=pkl).run()
-        except:
-            noti.telegram_to(botname='dart', text="Something wrong during AnalyseOneSubject()...")
+        except Exception as e:
+            # https://stackoverflow.com/questions/1483429/how-to-print-an-exception-in-python
+            import traceback
+            traceback.print_exc()
+            noti.telegram_to(botname='dart', text=f"Exception occurred during AnalyseOneSubject() : {e}")
         finally:
             if driver is not None:
                 # https://stackoverflow.com/questions/15067107/difference-between-webdriver-dispose-close-and-quit#:~:text=Close()%20%2D%20It%20is%20used,(Close%20all%20the%20windows).
@@ -308,7 +312,13 @@ def run_all_subjects(edate: str) -> int:
 if __name__ == '__main__':
     client = mongo2.connect_mongo(dbpath.load())
     driver = utils.get_driver()
-    edate = '20220308'
+    edate = '20220310'
+    run_all_subjects(edate)
+
+    """
+    client = mongo2.connect_mongo(dbpath.load())
+    driver = utils.get_driver()
+    edate = '20220310'
     p = Pickle()
     print(p.contents)
     if p.contents.date != edate:
@@ -317,3 +327,4 @@ if __name__ == '__main__':
         p.load()
     AnalyseOneSubject(client, driver, edate=edate, subject='매출액또는손익', pkl=p).run()
     print(p.contents)
+    """
\ No newline at end of file
