@@ -6,7 +6,7 @@ import pandas as pd
 
 from util_hj3415 import utils
 from db_hj3415 import mongo2, dbpath
-from .opendart import DartInfo
+from dart_hj3415.opendart import DartInfo
 
 import logging
 logger = logging.getLogger(__name__)
@@ -513,10 +513,14 @@ class 현물배당결정:
         self.__보통주당배당금 = float('nan')
         self.__우선주당배당금 = float('nan')
         # 현금배당성향이란 순이익중 배당금으로 지급된 금액을 말함
-        self.배당성향 = mongo2.C104(
-            client=mongo2.connect_mongo(dbpath.load()),
-            code=self.dartinfo.code,
-            page='c104y').find(title='현금배당성향(%)')
+        try:
+            self.배당성향 = mongo2.C104(
+                client=mongo2.connect_mongo(dbpath.load()),
+                code=self.dartinfo.code,
+                page='c104y').find(title='현금배당성향(%)')
+        except:
+            # 가끔 스크랩 오류로 데이터가 없는 경우가 있음.
+            self.배당성향 = {}
         self.보통주배당수익률 = 0.0
 
     @property
