@@ -12,8 +12,8 @@ from selenium.webdriver.common.by import By
 from db_hj3415 import mongo2
 from util_hj3415 import utils
 from typing import List
-from . import data
-from .opendart import DartInfo, Dart
+from dart_hj3415 import data
+from dart_hj3415.opendart import DartInfo, Dart
 
 import logging
 logger = logging.getLogger(__name__)
@@ -231,7 +231,10 @@ class 공급계약체결(DartSubject):
         최근매출액: 6366818031
         """
         def cal_comparative_point(big: float, small: float) -> (int, float):
-            ratio = ((big / small) - 1) * 100
+            try:
+                ratio = ((big / small) - 1) * 100
+            except ZeroDivisionError:
+                ratio = 0
             a = int(ratio / 10)
             return a if a <= DartSubject.MAX_POINT else DartSubject.MAX_POINT, round(ratio)
 
